@@ -82,7 +82,8 @@ DV : Concentration central
   #With initial eta = 0, this subject automatically converge to... 0.
 
   #Need a "reset" of the estimation with other values:
-  expect_warning(est_lbfgsb_reset <- mapbayest(model, data739, method = "L-BFGS-B", verbose = F, reset = T), "Error in optimization. Reset with new initial values:")
+  est_lbfgsb_reset <- mapbayest(model, data739, method = "L-BFGS-B", verbose = F, reset = T)
+  expect_gt(est_lbfgsb_reset$opt.value$run, 1)
   expect_equal(unname(round(est_lbfgsb_reset$final_eta[[1]], 4)), c(0.0477, -0.0314, -0.0007, -0.0738))
 
 })
@@ -130,7 +131,8 @@ $CAPTURE DV
   )
 
   est1 <- mapbayest(mod1, data1, verbose = F)
-  expect_warning(est2 <- mapbayest(mod1, data1, quantile_bound = 0.00001, verbose = F))
+  est2 <- mapbayest(mod1, data1, quantile_bound = 0.00001, verbose = F)
+  expect_gt(est2$opt.value$run, 1)
   est3 <- mapbayest(mod1, data1, quantile_bound = 0.00001, reset = F, verbose = F)
 
   expect_true(length(unique(abs(get_eta(est1)))) != 1)
@@ -179,7 +181,7 @@ $CAPTURE DV
     adm_lines(amt = 100) %>%
     obs_lines(time = c(1, 2, 6, 8), DV = c(0.87, 1.15, 1.07, 0.96)*10) %>% #Observations ten-fold higher than typical profile
     get_data()
-  expect_warning(est1 <- mapbayest(mod1, data1, verbose = F), "Reset with new bounds")
+  invisible(capture.output(expect_message(est1 <- mapbayest(mod1, data1), "Reset with new bounds")))
   expect_gt(unname(abs(get_eta(est1, 1))), est1$arg.optim$lower[1])
 
   est2 <- mapbayest(mod1, data1, verbose = FALSE, reset = FALSE)
